@@ -1,2 +1,3 @@
 from .fast_luks_lib import *
-from .luksctl_lib import *
\ No newline at end of file
+
+__version__ = '0.0.26'
\ No newline at end of file
